@@ -38,15 +38,9 @@ class BaseParser(object):
             self._debug('FAILED: RECURSION LIMIT REACHED', color='error')
             raise ScriptFailed('Recursion limit reached')
 
-        r = requests.get('http://cloudover.io/thunder/raw/' + params[0]).text.splitlines()
-        try:
-            self.recursion = self.recursion + 1
-            self._parse(r)
-        except ScriptDone as e:
-            pass
-        except Exception as e:
-            self._debug('FAILED: %s' % str(e), e, color='warning')
-            return
+        r = requests.get('http://cloudover.io/thunder/raw/' + self._parse_var(params[0])).text.splitlines()
+        self.recursion = self.recursion + 1
+        self._parse(r)
 
     def cmd_req_var(self, params):
         if ':' in params[0]:
